@@ -1,4 +1,4 @@
-require 'aruba/cucumber'
+require "aruba/cucumber"
 
 Aruba.configure do |config|
   config.exit_timeout                          = 120
