@@ -1,4 +1,4 @@
-if RUBY_PLATFORM == 'java'
+if RUBY_PLATFORM == "java"
   Before do
     @aruba_timeout_seconds = 15
   end
