@@ -6,7 +6,7 @@ Around do |scenario, block|
   name = if scenario.respond_to?(:feature) # Cucumber < 4
            "#{scenario.feature.file}::#{scenario.name}"
          else
-           "#{scenario.location.file}::#{scenario.name}"
+           "#{scenario.location.file}:#{scenario.location.line} # #{scenario.name}"
          end
 
   start = Time.now
@@ -20,6 +20,6 @@ at_exit do
   puts "------------- Top #{max_scenarios} slowest scenarios -------------"
   sorted_times = scenario_times.sort { |a, b| b[1] <=> a[1] }
   sorted_times[0..max_scenarios - 1].each do |key, value|
-    puts format('%.2f  %s', value, key)
+    puts format("%.2f  %s", value, key)
   end
 end
