@@ -1,7 +1,7 @@
-require 'pathname'
+require "pathname"
 
-require 'aruba/platform'
-require 'aruba/command'
+require "aruba/platform"
+require "aruba/command"
 
 # require 'win32/file' if File::ALT_SEPARATOR
 
@@ -22,7 +22,7 @@ module Aruba
       def which(program, path = nil)
         with_environment do
           # ENV is set within this block
-          path = ENV['PATH'] if path.nil?
+          path = ENV["PATH"] if path.nil?
 
           Aruba.platform.which(program, path)
         end
@@ -35,7 +35,7 @@ module Aruba
       def pipe_in_file(file_name)
         file_name = expand_path(file_name)
 
-        File.open(file_name, 'r').each_line do |line|
+        File.open(file_name, "r").each_line do |line|
           last_command_started.write(line)
         end
       end
@@ -152,7 +152,7 @@ module Aruba
 
         unless command.interactive?
           raise NotImplementedError,
-                'Running interactively is not supported with this process launcher.'
+                "Running interactively is not supported with this process launcher."
         end
 
         start_command(command)
@@ -226,13 +226,11 @@ module Aruba
         stop_signal       = opts[:stop_signal] || aruba.config.stop_signal
         startup_wait_time = opts[:startup_wait_time] || aruba.config.startup_wait_time
 
-        cmd = replace_variables(cmd)
-
         @commands ||= []
         @commands << cmd
 
         environment       = aruba.environment
-        working_directory = expand_path('.')
+        working_directory = expand_path(".")
         event_bus         = aruba.event_bus
 
         cmd = Aruba.platform.detect_ruby(cmd)
