@@ -1,10 +1,10 @@
-require 'pathname'
+require "pathname"
 
-require 'aruba/platform'
+require "aruba/platform"
 
-Aruba.platform.require_matching_files('../matchers/file/*.rb', __FILE__)
-Aruba.platform.require_matching_files('../matchers/directory/*.rb', __FILE__)
-Aruba.platform.require_matching_files('../matchers/path/*.rb', __FILE__)
+Aruba.platform.require_matching_files("../matchers/file/*.rb", __FILE__)
+Aruba.platform.require_matching_files("../matchers/directory/*.rb", __FILE__)
+Aruba.platform.require_matching_files("../matchers/path/*.rb", __FILE__)
 
 # Aruba
 module Aruba
@@ -67,7 +67,7 @@ module Aruba
       # @return [Array]
       #   List of files and directories
       def all_paths
-        list('.').map { |path| expand_path(path) }
+        list(".").map { |path| expand_path(path) }
       end
 
       # Return all existing files in current directory
@@ -75,7 +75,7 @@ module Aruba
       # @return [Array]
       #   List of files
       def all_files
-        list('.').select { |p| file? p }.map { |p| expand_path(p) }
+        list(".").select { |p| file? p }.map { |p| expand_path(p) }
       end
 
       # Return all existing directories in current directory
@@ -83,7 +83,7 @@ module Aruba
       # @return [Array]
       #   List of files
       def all_directories
-        list('.').select { |p| directory? p }.map { |p| expand_path(p) }
+        list(".").select { |p| directory? p }.map { |p| expand_path(p) }
       end
 
       # Create directory object
@@ -108,8 +108,8 @@ module Aruba
                 %(Only directories are supported. Path "#{name}" is not a directory.)
         end
 
-        existing_files            = Dir.glob(expand_path(File.join(name, '**', '*')))
-        current_working_directory = Pathname.new(expand_path('.'))
+        existing_files            = Dir.glob(expand_path(File.join(name, "**", "*")))
+        current_working_directory = Pathname.new(expand_path("."))
 
         existing_files.map do |d|
           Pathname.new(d).relative_path_from(current_working_directory).to_s
@@ -191,7 +191,7 @@ module Aruba
         end
 
         if source.count > 1 && exist?(destination) && !directory?(destination)
-          raise ArgumentError, 'Multiples sources can only be copied to a directory'
+          raise ArgumentError, "Multiples sources can only be copied to a directory"
         end
 
         source_paths     = source.map { |f| expand_path(f) }
@@ -240,7 +240,7 @@ module Aruba
         end
 
         if source.count > 1 && exist?(destination) && !directory?(destination)
-          raise ArgumentError, 'Multiple sources can only be copied to a directory'
+          raise ArgumentError, "Multiple sources can only be copied to a directory"
         end
 
         source_paths     = source.map { |f| expand_path(f) }
@@ -326,8 +326,29 @@ module Aruba
       def append_to_file(file_name, file_content)
         file_name = expand_path(file_name)
 
-        Aruba.platform.mkdir(File.dirname(file_name))
-        File.open(file_name, 'a') { |f| f << file_content }
+        File.open(file_name, "a") { |f| f << file_content }
+      end
+
+      # Append lines to a (text) file. This will make sure a newline is present
+      # between the old content and the new.
+      #
+      # @param [String] file_name
+      #   The name of the file to be used
+      #
+      # @param [String] file_content
+      #   The lines which should be appended to file
+      def append_lines_to_file(file_name, file_content)
+        file_name = expand_path(file_name)
+
+        last = File.open(file_name) do |f|
+          f.seek(-3, IO::SEEK_END)
+          f.read
+        end
+
+        File.open(file_name, "a") do |f|
+          f << "\n" unless last.end_with? "\n"
+          f << file_content
+        end
       end
 
       # Create a directory in current directory
@@ -385,7 +406,7 @@ module Aruba
       #   Bytes on disk
       def disk_usage(*paths)
         paths = paths.flatten
-        expect(paths).to Aruba::Matchers.all be_an_existing_path
+        expect(paths).to all be_an_existing_path
         expanded = paths.map { |path| expand_path(path) }
 
         Aruba.platform.determine_disk_usage(expanded)
