@@ -1,4 +1,4 @@
-require 'pathname'
+require "pathname"
 
 # Aruba
 module Aruba
@@ -57,7 +57,7 @@ module Aruba
     # Get path
     def to_pathname
       current_path = @obj.inject do |path, element|
-        if element.start_with?('~') ||
+        if element.start_with?("~") ||
            Aruba.platform.absolute_path?(element)
           element
         else
