@@ -1,7 +1,7 @@
-require 'irb'
+require "irb"
 
-require 'aruba/api'
-require 'aruba/console/help'
+require "aruba/api"
+require "aruba/console/help"
 
 # Aruba
 module Aruba
@@ -15,21 +15,21 @@ module Aruba
       ARGV.clear
       IRB.setup nil
 
-      IRB.conf[:IRB_NAME] = 'aruba'
+      IRB.conf[:IRB_NAME] = "aruba"
 
       IRB.conf[:PROMPT] = {}
       IRB.conf[:PROMPT][:ARUBA] = {
-        PROMPT_I: '%N:%03n:%i> ',
-        PROMPT_S: '%N:%03n:%i%l ',
-        PROMPT_C: '%N:%03n:%i* ',
+        PROMPT_I: "%N:%03n:%i> ",
+        PROMPT_S: "%N:%03n:%i%l ",
+        PROMPT_C: "%N:%03n:%i* ",
         RETURN: "# => %s\n"
       }
       IRB.conf[:PROMPT_MODE] = :ARUBA
 
       IRB.conf[:RC] = false
 
-      require 'irb/completion'
-      require 'irb/ext/save-history'
+      require "irb/completion"
+      require "irb/ext/save-history"
       IRB.conf[:READLINE] = true
       IRB.conf[:SAVE_HISTORY] = 1000
       IRB.conf[:HISTORY_FILE] = Aruba.config.console_history_file
@@ -43,14 +43,14 @@ module Aruba
         end
 
         def inspect
-          'nil'
+          "aruba console"
         end
       end
 
       irb = IRB::Irb.new(IRB::WorkSpace.new(context.new))
       IRB.conf[:MAIN_CONTEXT] = irb.context
 
-      trap('SIGINT') do
+      trap("SIGINT") do
         irb.signal_handle
       end
 
