@@ -1,4 +1,4 @@
-require 'aruba/api'
+require "aruba/api"
 
 # Aruba
 module Aruba
@@ -9,9 +9,9 @@ module Aruba
       # Output help information
       def aruba_help
         puts "Aruba Version: #{Aruba::VERSION}"
-        puts 'Issue Tracker: https://github.com/cucumber/aruba/issues'
-        puts 'Documentation:'
-        puts '* http://www.rubydoc.info/gems/aruba'
+        puts "Issue Tracker: https://github.com/cucumber/aruba/issues"
+        puts "Documentation:"
+        puts "* http://www.rubydoc.info/gems/aruba"
         puts
 
         nil
@@ -20,7 +20,7 @@ module Aruba
       # List available methods in aruba
       def aruba_methods
         ms = (Aruba::Api.instance_methods - Module.instance_methods)
-             .each_with_object([]) { |e, a| a << format('* %s', e) }
+             .each_with_object([]) { |e, a| a << format("* %s", e) }
              .sort
 
         puts "Available Methods:\n#{ms.join("\n")}"
