@@ -1,4 +1,4 @@
-require 'contracts'
+require "contracts"
 
 # Aruba
 module Aruba
@@ -14,6 +14,7 @@ module Aruba
 
       # Create contract
       def initialize(*vals)
+        super()
         @vals = vals
       end
 
