@@ -46,12 +46,12 @@ Given(/^(?:a|the) (\d+) byte file(?: named)? "([^"]*)"$/) do |file_size, file_na
 end
 
 Given(/^(?:an|the) empty file(?: named)? "([^"]*)"$/) do |file_name|
-  write_file(file_name, '')
+  write_file(file_name, "")
 end
 
 Given(/^(?:an|the) empty file(?: named)? "([^"]*)" with mode "([^"]*)"$/) \
   do |file_name, file_mode|
-  write_file(file_name, '')
+  write_file(file_name, "")
   chmod(file_mode, file_name)
 end
 
@@ -68,13 +68,17 @@ When(/^I append to "([^"]*)" with:$/) do |file_name, file_content|
   append_to_file(file_name, file_content)
 end
 
+When(/^I append the following lines to "([^"]*)":$/) do |file_name, file_content|
+  append_lines_to_file(file_name, file_content)
+end
+
 When(/^I append to "([^"]*)" with "([^"]*)"$/) do |file_name, file_content|
   append_to_file(file_name, file_content)
 end
 
 When(/^I remove (?:a|the) (?:file|directory)(?: named)? "([^"]*)"( with full force)?$/) \
   do |name, force_remove|
-  remove(name, force: force_remove.nil? ? false : true)
+  remove(name, force: !force_remove.nil?)
 end
 
 Given(/^(?:a|the) (?:file|directory)(?: named)? "([^"]*)" does not exist$/) do |name|
@@ -91,7 +95,7 @@ Then(/^the following files should (not )?exist:$/) do |negated, files|
   if negated
     expect(files).not_to include an_existing_file
   else
-    expect(files).to Aruba::Matchers.all be_an_existing_file
+    expect(files).to all be_an_existing_file
   end
 end
 
@@ -136,7 +140,7 @@ Then(/^the following directories should (not )?exist:$/) do |negated, directorie
   if negated
     expect(directories).not_to include an_existing_directory
   else
-    expect(directories).to Aruba::Matchers.all be_an_existing_directory
+    expect(directories).to all be_an_existing_directory
   end
 end
 
