@@ -1,4 +1,4 @@
-require 'aruba/matchers/base/message_indenter'
+require "aruba/matchers/base/message_indenter"
 
 # @!method have_output
 #   This matchers checks if <command> has created output
