@@ -1,7 +1,7 @@
 # @!method have_output_on_stdout
 #   This matchers checks if <command> has created output on stdout
 #
-#   @return [TrueClass, FalseClass] The result
+#   @return [Boolean] The result
 #
 #     false:
 #     * if command has not created output on stdout
@@ -17,7 +17,9 @@ RSpec::Matchers.define :have_output_on_stdout do |expected|
   match do |actual|
     @old_actual = actual
 
-    next false unless @old_actual.respond_to? :stdout
+    unless @old_actual.respond_to? :stdout
+      raise "Expected #{@old_actual} to respond to #stdout"
+    end
 
     @old_actual.stop
 
