@@ -1,5 +1,4 @@
-require 'rspec/expectations/version'
-require 'shellwords'
+require "shellwords"
 
 # @!method be_an_existing_executable
 #   This matchers checks if <file> exists in filesystem
