@@ -1,5 +1,4 @@
-require 'rspec/expectations/version'
-require 'fileutils'
+require "fileutils"
 
 # @!method have_same_file_content_as(file_name)
 #   This matchers checks if <file1> has the same content like <file2>
