@@ -18,7 +18,7 @@
 #     end
 RSpec::Matchers.define :match_output_string do |expected|
   match do |actual|
-    actual.force_encoding('UTF-8')
+    actual.force_encoding("UTF-8")
     @expected = Regexp.new(unescape_text(expected), Regexp::MULTILINE)
     @actual   = sanitize_text(actual)
 
