@@ -27,7 +27,7 @@ module Aruba
       #   The table
       def to_s
         longest_key = hash.keys.map(&:to_s).max_by(&:length)
-        return '' if longest_key.nil?
+        return "" if longest_key.nil?
 
         name_size = longest_key.length
 
