@@ -70,7 +70,7 @@ module Aruba
       #
       # @param [String] path
       #   ENV['PATH']
-      def call(program, path = ENV['PATH'])
+      def call(program, path = ENV["PATH"])
         raise ArgumentError, "ENV['PATH'] cannot be empty" if path.nil? || path.empty?
 
         program = program.to_s
