@@ -1,9 +1,7 @@
-require 'cucumber/platform'
-
-require 'aruba/platforms/unix_platform'
-require 'aruba/platforms/windows_command_string'
-require 'aruba/platforms/windows_environment_variables'
-require 'aruba/platforms/windows_which'
+require "aruba/platforms/unix_platform"
+require "aruba/platforms/windows_command_string"
+require "aruba/platforms/windows_environment_variables"
+require "aruba/platforms/windows_which"
 
 # Aruba
 module Aruba
@@ -20,7 +18,7 @@ module Aruba
     # @private
     class WindowsPlatform < UnixPlatform
       def self.match?
-        Cucumber::WINDOWS
+        Gem.win_platform?
       end
 
       # @see UnixPlatform#command_string
@@ -34,7 +32,7 @@ module Aruba
       end
 
       # @see UnixPlatform#which
-      def which(program, path = ENV['PATH'])
+      def which(program, path = ENV["PATH"])
         WindowsWhich.new.call(program, path)
       end
 
