@@ -1,10 +1,10 @@
-require 'childprocess'
-require 'tempfile'
-require 'shellwords'
+require "childprocess"
+require "tempfile"
+require "shellwords"
 
-require 'aruba/errors'
-require 'aruba/processes/basic_process'
-require 'aruba/platform'
+require "aruba/errors"
+require "aruba/processes/basic_process"
+require "aruba/platform"
 
 # Aruba
 module Aruba
@@ -67,31 +67,28 @@ module Aruba
         if started?
           error_message =
             "Command \"#{commandline}\" has already been started." \
-            ' Please `#stop` the command first and `#start` it again.' \
-            ' Alternatively use `#restart`.'
+            " Please `#stop` the command first and `#start` it again." \
+            " Alternatively use `#restart`."
           raise CommandAlreadyStartedError, error_message
         end
 
         @started = true
 
         @process = ChildProcess.build(*command_string.to_a)
-        @stdout_file = Tempfile.new('aruba-stdout-')
-        @stderr_file = Tempfile.new('aruba-stderr-')
+        @stdout_file = Tempfile.new("aruba-stdout-")
+        @stderr_file = Tempfile.new("aruba-stderr-")
 
         @stdout_file.sync = true
         @stderr_file.sync = true
 
-        if RUBY_VERSION >= '1.9'
-          @stdout_file.set_encoding('ASCII-8BIT')
-          @stderr_file.set_encoding('ASCII-8BIT')
-        end
+        @stdout_file.set_encoding("ASCII-8BIT")
+        @stderr_file.set_encoding("ASCII-8BIT")
 
         @exit_status = nil
         @duplex      = true
 
         before_run
 
-        @process.leader    = true
         @process.io.stdout = @stdout_file
         @process.io.stderr = @stderr_file
         @process.duplex    = @duplex
@@ -275,12 +272,10 @@ module Aruba
 
       def command_path
         @command_path ||=
-          begin
-            if Aruba.platform.builtin_shell_commands.include?(command)
-              command
-            else
-              Aruba.platform.which(command, environment['PATH'])
-            end
+          if Aruba.platform.builtin_shell_commands.include?(command)
+            command
+          else
+            Aruba.platform.which(command, environment["PATH"])
           end
       end
 
@@ -295,7 +290,7 @@ module Aruba
         data = file.read
         file.close
 
-        data.force_encoding('UTF-8')
+        data.force_encoding("UTF-8")
       end
     end
   end
