@@ -1,29 +1,29 @@
-require 'spec_helper'
-require 'aruba/api'
-require 'fileutils'
+require "spec_helper"
+require "aruba/api"
+require "fileutils"
 
 RSpec.describe Aruba::Api::Commands do
-  include_context 'uses aruba API'
+  include_context "uses aruba API"
 
-  describe '#run_command' do
-    context 'when succesfully running a command' do
-      before { @aruba.run_command 'cat' }
+  describe "#run_command" do
+    context "when succesfully running a command" do
+      before { @aruba.run_command "cat" }
 
       after { @aruba.all_commands.each(&:stop) }
 
-      it 'respond to input' do
-        @aruba.type 'Hello'
+      it "respond to input" do
+        @aruba.type "Hello"
         @aruba.type "\u0004"
-        expect(@aruba.last_command_started).to have_output 'Hello'
+        expect(@aruba.last_command_started).to have_output "Hello"
       end
 
-      it 'respond to close_input' do
-        @aruba.type 'Hello'
+      it "respond to close_input" do
+        @aruba.type "Hello"
         @aruba.close_input
-        expect(@aruba.last_command_started).to have_output 'Hello'
+        expect(@aruba.last_command_started).to have_output "Hello"
       end
 
-      it 'pipes data' do
+      it "pipes data" do
         @aruba.write_file(@file_name, "Hello\nWorld!")
         @aruba.pipe_in_file(@file_name)
         @aruba.close_input
@@ -31,7 +31,7 @@ RSpec.describe Aruba::Api::Commands do
       end
     end
 
-    context 'when mode is :in_process' do
+    context "when mode is :in_process" do
       before do
         @aruba.aruba.config.command_launcher = :in_process
       end
@@ -40,16 +40,16 @@ RSpec.describe Aruba::Api::Commands do
         @aruba.aruba.config.command_launcher = :spawn
       end
 
-      it 'raises an error' do
-        expect { @aruba.run_command 'cat' }.to raise_error NotImplementedError
+      it "raises an error" do
+        expect { @aruba.run_command "cat" }.to raise_error NotImplementedError
       end
     end
 
-    context 'when running a relative command' do
-      let(:cmd) { Cucumber::WINDOWS ? 'bin/testcmd.bat' : 'bin/testcmd' }
+    context "when running a relative command" do
+      let(:cmd) { Gem.win_platform? ? "bin/testcmd.bat" : "bin/testcmd" }
 
       before do
-        if Cucumber::WINDOWS
+        if Gem.win_platform?
           @aruba.write_file cmd, <<~BAT
             exit 0
           BAT
@@ -62,7 +62,7 @@ RSpec.describe Aruba::Api::Commands do
         end
       end
 
-      it 'finds the command from the test directory' do
+      it "finds the command from the test directory" do
         run_command(cmd)
         expect(last_command_started).to be_successfully_executed
       end
