@@ -1,9 +1,9 @@
-require 'spec_helper'
+require "spec_helper"
 
 RSpec.describe Aruba::Command do
-  subject(:command) do
+  let(:command) do
     described_class.new(
-      'true',
+      "true",
       event_bus: event_bus,
       exit_timeout: exit_timeout,
       io_wait_timeout: io_wait_timeout,
@@ -15,63 +15,81 @@ RSpec.describe Aruba::Command do
     )
   end
 
-  let(:event_bus) { instance_double('Aruba::EventBus') }
+  let(:event_bus) { instance_double(Aruba::EventBus) }
   let(:exit_timeout) { 0.01 }
   let(:io_wait_timeout) { 0.01 }
-  let(:working_directory) { expand_path('.') }
+  let(:working_directory) { File.expand_path(".") }
   let(:environment) { ENV.to_hash }
   let(:main_class) { nil }
   let(:stop_signal) { nil }
   let(:startup_wait_time) { 0.01 }
 
-  describe '#start' do
+  describe "#start" do
     before do
       allow(event_bus).to receive(:notify).with(Aruba::Events::CommandStarted)
       command.start
     end
 
-    it 'leaves the command in the started state' do
+    it "leaves the command in the started state" do
       expect(command).to be_started
     end
   end
 
-  describe '#stop' do
+  describe "#stop" do
     before do
       allow(event_bus).to receive(:notify).with(Aruba::Events::CommandStarted)
       allow(event_bus).to receive(:notify).with(Aruba::Events::CommandStopped)
       command.start
-      command.stop
     end
 
-    it { is_expected.to be_stopped }
+    it "stops the command" do
+      command.stop
+      expect(command).to be_stopped
+    end
 
-    it 'notifies the event bus only once per run' do
+    it "notifies the event bus" do
       command.stop
       expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
     end
 
-    it 'prevents #terminate from notifying the event bus' do
+    it "notifies the event bus only once per run" do
+      command.stop
+      command.stop
+      expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
+    end
+
+    it "prevents #terminate from notifying the event bus" do
+      command.stop
       command.terminate
       expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
     end
   end
 
-  describe '#terminate' do
+  describe "#terminate" do
     before do
       allow(event_bus).to receive(:notify).with(Aruba::Events::CommandStarted)
       allow(event_bus).to receive(:notify).with(Aruba::Events::CommandStopped)
       command.start
-      command.terminate
     end
 
-    it { is_expected.to be_stopped }
+    it "stops the command" do
+      command.terminate
+      expect(command).to be_stopped
+    end
 
-    it 'notifies the event bus only once per run' do
+    it "notifies the event bus" do
       command.terminate
       expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
     end
 
-    it 'prevents #stop from notifying the event bus' do
+    it "notifies the event bus only once per run" do
+      command.terminate
+      command.terminate
+      expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
+    end
+
+    it "prevents #stop from notifying the event bus" do
+      command.terminate
       command.stop
       expect(event_bus).to have_received(:notify).with(Aruba::Events::CommandStopped).once
     end
