@@ -1,9 +1,9 @@
-require 'spec_helper'
+require "spec_helper"
 
 RSpec.describe Aruba::Configuration do
-  it_behaves_like 'a basic configuration'
+  it_behaves_like "a basic configuration"
 
-  context 'when is modified' do
+  context "when is modified" do
     let(:config) { described_class.new }
 
     it "won't allow bad values" do
