@@ -1,4 +1,4 @@
-require 'spec_helper'
+require "spec_helper"
 
 RSpec.describe Aruba::CommandMonitor do
   let(:monitor) { described_class.new(announcer: announcer) }
@@ -6,13 +6,13 @@ RSpec.describe Aruba::CommandMonitor do
   let(:process) { instance_double(Aruba::Processes::BasicProcess) }
 
   before do
-    allow(process).to receive(:commandline).and_return('foobar')
+    allow(process).to receive(:commandline).and_return("foobar")
     monitor.register_command(process)
   end
 
-  describe '#find' do
-    it 'works' do
-      expect(monitor.find('foobar')).to eq(process)
+  describe "#find" do
+    it "works" do
+      expect(monitor.find("foobar")).to eq(process)
     end
   end
 end
