@@ -1,12 +1,12 @@
-require 'rspec/core'
-require 'aruba/api'
+require "rspec/core"
+require "aruba/api"
 
 RSpec.configure do |config|
   config.filter_run focus: true
 
   config.run_all_when_everything_filtered = true
 
-  config.example_status_persistence_file_path = 'spec/examples.txt'
+  config.example_status_persistence_file_path = "tmp/rspec-examples.txt"
   config.profile_examples = 10
 
   config.expect_with :rspec do |c|
